summaryrefslogtreecommitdiff
path: root/Master/texmf-dist/scripts/texlive/tlmgr.pl
diff options
context:
space:
mode:
authorKarl Berry <karl@freefriends.org>2020-03-02 17:58:52 +0000
committerKarl Berry <karl@freefriends.org>2020-03-02 17:58:52 +0000
commite100c6f5746e458cfc7fad4b87ec6a6d0535dd91 (patch)
tree022d7e48581c4e9db0664a2fecfcbd851f0b7ecd /Master/texmf-dist/scripts/texlive/tlmgr.pl
parent6e9c8b8f8fae520435807e8081bb37618409aec6 (diff)
new luajithbtex engine (not on all platforms)
git-svn-id: svn://tug.org/texlive/trunk@54001 c570f23f-e606-0410-a88d-b1316a301751
Diffstat (limited to 'Master/texmf-dist/scripts/texlive/tlmgr.pl')
-rwxr-xr-xMaster/texmf-dist/scripts/texlive/tlmgr.pl14
1 files changed, 8 insertions, 6 deletions
diff --git a/Master/texmf-dist/scripts/texlive/tlmgr.pl b/Master/texmf-dist/scripts/texlive/tlmgr.pl
index afc483458ed..eca26a6f284 100755
--- a/Master/texmf-dist/scripts/texlive/tlmgr.pl
+++ b/Master/texmf-dist/scripts/texlive/tlmgr.pl
@@ -5714,7 +5714,7 @@ sub check_executes {
next if ($name eq "cont-en"); # too confusing
# we check that the name exist in bin/$arch
if (",$TeXLive::TLConfig::PartialEngineSupport," =~ /,$engine,/) {
# luajittex is special since it is not available on all architectures
# due to inherent reasons (machine code);
# luahbtex is special until we build it everywhere for TL'20.
#
@@ -5726,7 +5726,7 @@ sub check_executes {
# * if tlpkg/tlpsrc/<engine>.tlpsrc is *not* available (i.e., not
# the development tree) we just ignore it completely.
my $pkg;
- if ($engine eq "luajittex") {
+ if ($engine =~ /luajit(hb)?tex/) {
$pkg = "luajittex";
} elsif ($engine eq "luahbtex") {
$pkg = "luahbtex";
@@ -7144,11 +7144,13 @@ and the repository are not compatible:
# check for being frozen
if ($remotetlpdb->config_frozen) {
my $frozen_msg = <<FROZEN;
-TeX Live $TeXLive::TLConfig::ReleaseYear is frozen forever and will no
-longer be updated. This happens in preparation for a new release.
+TeX Live $TeXLive::TLConfig::ReleaseYear is frozen and will no longer
+be routinely updated. This happens in preparation for a new release.
+
+If you're willing to help with pretesting the new release, and we hope
+you are, (when pretests are available), please read
+https://tug.org/texlive/pretest.html.
-If you're interested in helping to pretest the new release (when
-pretests are available), please read https://tug.org/texlive/pretest.html.
Otherwise, just wait, and the new release will be ready in due time.
FROZEN
# don't die here, we want to allow updates even if tlnet is frozen!
@@ -5714,7 +5714,7 @@ sub check_executes {
# we check that the name exist in bin/$arch
if (",$TeXLive::TLConfig::PartialEngineSupport," =~ /,$engine,/) {
- # luajittex is special since it is not available on all architectures
+ # luajit[hb]tex is special since it is not available on all architectures
# due to inherent reasons (machine code);
# luahbtex is special until we build it everywhere for TL'20.